Index: src/dateparser.h |
diff --git a/src/dateparser.h b/src/dateparser.h |
index ad9ce70ab79145d78fa1fdb484b20327aebbcde6..484e1d3eca881cf9288bc18e27d6f0c93f610416 100644 |
--- a/src/dateparser.h |
+++ b/src/dateparser.h |
@@ -352,16 +352,14 @@ class DateParser : public AllStatic { |
bool is_iso_date_; |
}; |
// Tries to parse an ES6 Date Time String. Returns the next token |
// to continue with in the legacy date string parser. If parsing is |
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful, |
// returns DateToken::Invalid(). Otherwise parsing continues in the |
// legacy parser. |
template <typename Char> |
- static DateParser::DateToken ParseES6DateTime( |
- DateStringTokenizer<Char>* scanner, |
- DayComposer* day, |
- TimeComposer* time, |
+ static DateParser::DateToken ParseES5DateTime( |
+ DateStringTokenizer<Char>* scanner, DayComposer* day, TimeComposer* time, |
TimeZoneComposer* tz); |
}; |
@@ -352,16 +352,14 @@ class DateParser : public AllStatic { |
bool is_iso_date_; |
}; |
- // Tries to parse an ES6 Date Time String. Returns the next token |
+ // Tries to parse an ES5 Date Time String. Returns the next token |
// to continue with in the legacy date string parser. If parsing is |
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful, |